@@ -1,12 +1,14 @@
 """
 --wip scripts
 """
-
-from termcolor import colored
 from pygitscrum.git import git_code, git_code_silent
 from pygitscrum.scan import absolute_path_without_git
 from pygitscrum.args import compute_args
-from pygitscrum.print import print_debug, print_resume_list, print_g
+from pygitscrum.print import (
+    print_debug,
+    print_resume_list,
+    print_g,
+)
 
 
 def git_show(files):
@@ -17,7 +19,6 @@ def git_show(files):
     for repo in files:
         repo = absolute_path_without_git(repo)
         print_debug(repo + " ... ")
-
         item = compute_args().show
         if (
             git_code_silent(
@@ -36,6 +37,7 @@ def git_show(files):
                 print_g(repo)
                 answer = input("see the object (Y/n) ? ")
                 if answer.lower() in ["y", ""]:
+
                     git_code(
                         repo,
                         [
